==> haskell-hls-graph-1.9.0.0-117-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-graph
version:              1.9.0.0
visibility:           public
id:                   hls-graph-1.9.0.0-4nTvQprVee21P1DngyVSFV
key:                  hls-graph-1.9.0.0-4nTvQprVee21P1DngyVSFV
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  1db27e52a1e08441f4cea05d21b50c17
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-graph-1.9.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-graph-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-1.9.0.0-4nTvQprVee21P1DngyVSFV
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    async-2.2.5-b1lsUdcpsoF4yB7f3qI00 base-4.16.4.0 bytestring-0.11.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 directory-1.3.6.2
    exceptions-0.10.4 extra-1.7.14-JZwVFNOTzAl9wNXhTRS6o8
    filepath-1.4.2.2 focus-1.0.3.2-AKC1YexAFjH6ZbwqCay7au
    hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc
    js-dgtable-0.5.2-9QcYNIrannTBnclkJddG4d
    js-flot-0.8.3-CzHXKBaovyL8SpvVY5AoqF
    js-jquery-3.3.1-GXzGVnDeO0b1NTJdvMEVkL
    list-t-1.0.5.4-F3DLF2fJQIg5JN1yChcuYQ stm-2.5.0.2
    stm-containers-1.2.0.3-1iDLVR51EHg5hAxeIwDw4A text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-0.2.25.0-56sfjNmy7BWDzWuwznFqC8
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-graph-1.9.0.0-143-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-graph
version:              1.9.0.0
visibility:           public
id:                   hls-graph-1.9.0.0-7y2pZvkYmIwHHyfFLNsbki
key:                  hls-graph-1.9.0.0-7y2pZvkYmIwHHyfFLNsbki
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  0c8352bdbadd38d8a2e6e3127b8f02a3
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-graph-1.9.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-graph-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-1.9.0.0-7y2pZvkYmIwHHyfFLNsbki
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    directory-1.3.6.2 exceptions-0.10.4
    extra-1.7.15-9PmwGQvWkElDwGNWrixqMB filepath-1.4.2.2
    focus-1.0.3.2-IjqLHmM7ikd6sj5IAkH1BR
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    js-dgtable-0.5.2-9QcYNIrannTBnclkJddG4d
    js-flot-0.8.3-CzHXKBaovyL8SpvVY5AoqF
    js-jquery-3.3.1-9Wc6wKLcwFFKXShnmHX4Xv
    list-t-1.0.5.4-LWiXdd1SWXLJ5ZwTilo6U3 stm-2.5.0.2
    stm-containers-1.2.0.3-G8pIXUP0Zco3FhK4OwgNzU text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-0.2.25.0-LM0KsdTS0NHVSVsirPxfP
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
